==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/GIOApiTunnelConfigResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for GIOApiTunnelConfig
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class GIOApiTunnelConfigResponseProjection extends GraphQLResponseProjection {

    public GIOApiTunnelConfigResponseProjection() {
    }

    @Override
    public GIOApiTunnelConfigResponseProjection all$() {
        return all$(3);
    }

    @Override
    public GIOApiTunnelConfigResponseProjection all$(int maxDepth) {
        this.projectUid();
        this.projectKey();
        this.token();
        this.typename();
        return this;
    }

    public GIOApiTunnelConfigResponseProjection projectUid() {
        return projectUid(null);
    }

    public GIOApiTunnelConfigResponseProjection projectUid(String alias) {
        fields.add(new GraphQLResponseField("projectUid").alias(alias));
        return this;
    }

    public GIOApiTunnelConfigResponseProjection projectKey() {
        return projectKey(null);
    }

    public GIOApiTunnelConfigResponseProjection projectKey(String alias) {
        fields.add(new GraphQLResponseField("projectKey").alias(alias));
        return this;
    }

    public GIOApiTunnelConfigResponseProjection token() {
        return token(null);
    }

    public GIOApiTunnelConfigResponseProjection token(String alias) {
        fields.add(new GraphQLResponseField("token").alias(alias));
        return this;
    }

    public GIOApiTunnelConfigResponseProjection typename() {
        return typename(null);
    }

    public GIOApiTunnelConfigResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/GIOApiTunnelConfigResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for GIOApiTunnelConfig
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class GIOApiTunnelConfigResponseProjection extends GraphQLResponseProjection {

    public GIOApiTunnelConfigResponseProjection() {
    }

    @Override
    public GIOApiTunnelConfigResponseProjection all$() {
        return all$(3);
    }

    @Override
    public GIOApiTunnelConfigResponseProjection all$(int maxDepth) {
        this.projectUid();
        this.projectKey();
        this.token();
        this.typename();
        return this;
    }

    public GIOApiTunnelConfigResponseProjection projectUid() {
        return projectUid(null);
    }

    public GIOApiTunnelConfigResponseProjection projectUid(String alias) {
        fields.add(new GraphQLResponseField("projectUid").alias(alias));
        return this;
    }

    public GIOApiTunnelConfigResponseProjection projectKey() {
        return projectKey(null);
    }

    public GIOApiTunnelConfigResponseProjection projectKey(String alias) {
        fields.add(new GraphQLResponseField("projectKey").alias(alias));
        return this;
    }

    public GIOApiTunnelConfigResponseProjection token() {
        return token(null);
    }

    public GIOApiTunnelConfigResponseProjection token(String alias) {
        fields.add(new GraphQLResponseField("token").alias(alias));
        return this;
    }

    public GIOApiTunnelConfigResponseProjection typename() {
        return typename(null);
    }

    public GIOApiTunnelConfigResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}
